.Nh 1 "Advanced Topics"
.PP
cmusic is a complex program, and uses for it can be even more complex.
making it impossible to discuss cmusic applications in any comprehensive way.
This section includes some suggestions, hints, kinks, and a little
speculation about how cmusic may be used.
.Nh 2 Documentation
.PP
First of all, this document is probably obsolete even as you read it.
cmusic is a research program, which means that its properties vary
from time to time, new commands and unit generators are implemented,
old bugs get fixed, and new techniques are discovered.
Where this document and the online documentation differ, the online 
documentation will nearly always be correct.
.PP
This implies that it will be extremely helpful for the reader to become as
adroit as possible in understanding how to use the online 
documentation\(emnot only for cmusic\(embut for all CARL software.
.PP
The major sources of information aside from the \f2CARL Startup Kit\f1
are the \f2help\f1 and \f2man\f1 commands.
The difference between \f2help\f1 ``files'' and \f2man\f1 ``pages'' is
largely academic\(emoriginally the idea of a \f2man\f1 page was that
.UX
programs were to be so simple that they would require just one reference 
page for their full explanation to an advanced user.
Needless to say, many programs are so complicated as to make this a
prime example of wishful thinking.
.PP
Nevertheless, \f2man\f1 ``pages'' are still considered to be \f2definitive\f1
documents about the operation of any program they describe.
They are not, however, intended to be \f2tutorial\f1\(emthey are references
only, and for advanced users at that!
.PP
\f2help\f1 ``files'' are intended to provide extensions to the \f2man\f1 pages
for users needing more ``help'': they often include tutorial examples,
for instance.
.PP
Online documentation takes some getting used to, and many people find it
a bit difficult to follow, since a terminal screen is not so pleasing to
the eye as good quality hardcopy.
Nevertheless, things change too quickly to allow revisions of hardcopy
documents for each and every change in programs, let alone operating systems.
.Nh 2 "Debugging cmusic Scores"
.PP
Two useful debugging tools built into cmusic are the
\f2verbose\f1 and \f2list\f1 file options, both of which produce a
blow-by-blow description of what cmusic is up to at any given moment.
.PP
The \f2verbose\f1 mode can be used with short scores (it can be turned on
either with the ``set verbose ;'' statement or via the \(miv flag when
cmusic is run).
For longer runs, however, the ``set list ;'' option is often indispensable.
.PP
A useful technique is to create a ``.list'' file with the same first name
as the score file by including the ``set list ;'' statement at the head of
a score\(emtypically right after the ``#include <carl/cmusic.h>'' statement.
The
.UX
``tail'' command may be used at any time to examine the last few lines of
the ``.list'' file, and the ``tail \(mif'' command option allows the user
to attach the terminal to a growing ``.list'' file in a revokable
manner.
.PP
If things seem to be going poorly\(emfor example, no sound comes out\(emit
is often helpful to examine the signals passing among the unit generators
in the instruments being played.
This can be done by ``commenting out'' certain of the original unit generator
statements (by enclosing them in curly braces) and attaching the output
of a questionable signal directly to the \f2out\f1 unit generator.
The signal will then pour onto the user's terminal screen if cmusic is
run with its standard output connected to the terminal.
.PP
Observation of such signals is often difficult because there are just
so many numbers that their pattern can be difficult to see.
One technique here is to reduce the sampling rate temporarily (use the
\(miR flag), and/or to attach the cmusic output to a graphics program
such as ``graph.''
If cmusic output is connected to a
.UX
pipe, cmusic will produce binary floatsams, and ``graph'' requires ASCII
input.
A CARL utility program called ``btoa'' is provided specifically for insertion
into a pipe-line where sample data must be converted from binary to ASCII.
For example, the commands
.DS
cmusic score.sc
.DE
and
.DS
cmusic score.sc | btoa
.DE
produce exactly the same list of numbers on the user's terminal.
.PP
The technique of ``commenting out'' score statements applies equally well
to note lists.
Often it is desirable to run just a portion of a score for testing 
purposes\(emcurly braces may be used to temporarily turn off a part of
the score (but be careful about action times, or you may accidentally specify
that 100 seconds of silence are to be generated before any note will sound!).
.PP
Clicks are a perennial problem in digital sound synthesis.
Clicks are caused by discontinuities in the waveform of the digital
signal.
Such discontinuities can arise from many sources.
.PP
Turning on or shutting off a note with a nonzero amplitude will almost always
create a click.
Care must be exercised to ensure that envelope functions really begin and
end with 0.0, and that they don't rise (or fall) too rapidly from this
value of infinite repose.
Even an overly-enthusiastic attack time can create a click sometimes and not
others, depending on where the peaks of the enveloped waveform happen to
fall under the control curve.
.PP
Clicks may suddenly appear when a sound is spatialized with the \f2space\f1
unit generator, even if no clicks were evident in the original sound, due
to the click-enhancing effect of reverberation.
Discontinuities in sound paths are translated directly into amplitude 
discontinuities\(emas when the sound source suddenly goes from here to there
without going in between\(emoften making it necessary to use \f2iosc\f1
instead of \f2osc\f1 unit generators for soundpath control.
.PP
Any time the magnitude of the total amplitude exceeds 1.0, cmusic is forced
to ``clip'' offending samples in a way reminiscent of hard analog 
limiting\(emso hard, in fact, that the sound is easily disfigured by it.
.PP
Even a sudden change of a non-amplitude parameter\(emsuch as frequency\(emcan
produce clicks under certain circumstances, depending on the abruptness
of the waveform change.
.Nh 2 "Oscillator Phase Connection"
.PP
The oscillator unit generators all use sum locations that are typically
attached to dynamic state variables ($d$'s).
Such variables are allocated at the beginning of a note as needed, and their
values are initialized to 0.0.
Thus, two contiguous, non-enveloped notes in a row on an \f2osc\f1 unit 
generator are likely to produce a click because the oscillator phase will
be reset at the beginning of each note, as shown in the following
score example.
.DS
#include <carl/cmusic.h>
ins 0 toot ;
    osc b1 p5 p6 f1 d ;
    out b1 ;
end ;
SINE(f1) ;
note 0 toot 1 \(mi6dB 100Hz ;
note 1 toot 1 \(mi6dB 110Hz ;
ter ;
.DE
.PP
A useful technique for ``connecting'' the phase of the two notes is to use
a global variable ($v$) for the oscillator sum location\(emthis memory
location is allocated \f2permanently\f1 (for the duration of the run), so
the phase (i.e., sum-of-increments) value at the end of the first note
will be remembered at the beginning of the second, as in the following example:
.DS
#include <carl/cmusic.h>
ins 0 toot ;
    osc b1 p5 p6 f1 v1 ;
    out b1 ;
end ;
SINE(f1) ;
note 0 toot 1 \(mi6dB 100Hz ;
note 1 toot 1 \(mi6dB 110Hz ;
ter ;
.DE
.PP
The beginning of the second note in the last example is very likely \f2not\f1
to produce a click because the change in frequency between the two notes
is not too great.
Note, however, that it is now impossible to play more than one note at a time
on instrument \f2toot\f1, since two simultaneous notes would compete
destructively for the contents of global variable $v1$.
.Nh 2 "Global Control"
.PP
cmusic operates by observing the action time of the command at hand in the
score, starting from the beginning, of course.
Once an action time is encountered that is greater than the ``current''
action time (the greatest time to which sound has been synthesized),
cmusic starts generating samples.
Sample generation continues until ``something happens'', which means that
either a command is to be executed, or a note terminates, in which case
resources for that note must be deallocated.
.PP
cmusic does not produce one sample at a time but runs in \f2blocks\f1 of
samples\(emthe length of a sample synthesis block is equal to the length
of the i/o blocks ($b$'s).
.PP
For example, if it is time to start synthesizing a note, cmusic looks up
the definition for the relevant instrument and calls the unit
generator programs one at a time in the order they are stated in the
instrument definition.
Information is passed to the individual unit generators about where to
find information about parameter information\(ema $b$ will be a pointer to
an array (i/o block), a $p$ will point to a single value within the list of
note parameters for the current note, and so on.
Each unit generator is instructed to generate either $B$ samples (where
$B$ is the number of samples in an i/o block), or fewer, if the note
is to terminate before $B$ samples have gone by from the current synthesis
time.
.PP
This manner of operation allows an interesting form of global control
to be used by the cmusic score-writer.
A ``dummy'' instrument may be defined that outputs into an i/o block,
let's say a \f2shape\f1 unit generator outputs into $b10$, as in the 
following example:
.DS
ins 0 cresc ;
    shape b10 f2 d ;
end ;
GEN4(f2) 0,\(mi30dB \(mi2 1,\(mi20dB ;
.DE
Notice that there is no \f2out\f1 unit generator included in the definition
of instrument \f2cresc\f1.
The values in $b10$ seem to be going nowhere!
.PP
Other instruments, however, may refer to $b10$ as part of their definitions.
In this case, since the $b10$ values will gradually change from \(mi30 to
\(mi20\ dB over the course of any note played on instrument \f2cresc\f1, we
may deduce that it is designed for longterm amplitude control.
In fact, \f2cresc\f1 will produce a \f2crescendo\f1 when used in conjunction
with other instruments in the following manner:
.DS
ins 0 cresc ;
    shape b10 f2 d ;
end ;
GEN4(f2) 0,\(mi30dB \(mi2 1,\(mi20dB ;
ins 0 toot ;
    seg b1 b10 f3 d p6 0 p7 ;
    osc b1 b1 p5 f1 d ;
    out b1 ;
end ;
GEN4(f3) 0,0 \(mi3 1/3,1 0 2/3,.1 \(mi2 1,0 ;
SAWTOOTH(f1) ;

note 0 cresc 5 ; {crescendo over 5 seconds}

note 0 toot 1 A(0) .1sec .1sec ;
note 0 toot 1 Cs(1) .1sec .1sec ;

note 2 toot 1.5 B(0) .05sec .1sec ;
note 2.3 toot 2 Ds(1) .05sec .1sec ;

note 3.6 toot 1.4 E(1) .01sec .1sec ;

sec ;
.DE
.PP
Several advanced techniques are demonstrated in this example.
.PP
First, $b10$ is used to control the amplitude of another instrument, which
plays chords with various pitches and attack times.
$b10$ is simply fed into the $amp$ input of the $seg$ unit generator controlling
the peak note amplitude\(emthe amplitude envelopes are continuously being
fed a greater and greater peak value as the first five seconds of the score
go by.
.PP
Second, $b1$ is used both as an input and an output of the $osc$ unit generator.
This is perfectly legal since the information in $b1$ is examined before the
output is produced\(emwe only have to be careful not to use the same
i/o block to hold more than one thing at one time!
No unit generator may use $b10$ while the \f2cresc\f1 unit generator is
operating, for example.
.PP
This demonstrates that even though i/o blocks are dynamic they are
allocated at the beginning of any note that uses them, and
remain usable as long as that note event is active.
Their contents will always be whatever was last put there from any source.
.PP
Such global control techniques may be used for more than the production of
\f2crescendi\f1, of course.
Any and all instrument parameters may be modulated in this way, yielding
an entire layer of control possibilities independent of the note
event level.
.Nh 2 "Advanced Uses of sndfile"
.PP
The sndfile unit generator allows cmusic to be used as a general mixing
program for digital recordings and soundfiles that result from other
synthesis runs.
Global control functions may be used to specify long term mixing levels,
filtering (equalization) parameters, panning, spatialization, and so on.
.PP
In addition, the sndfile unit generator can be used to read in the
results of sound analysis programs such as the \f2phase vocoder\f1 (\f2pvoc\f1).
pvoc analysis output may be viewed as the output of a large number of
special bandpass filters, where each pvoc filter describes the
time varying amplitude and frequency of an individual sinusoidal component that
lies within its bandpass region.
.PP
With the proper flag specifications (see the pvoc documentation)
pvoc analysis results may be stored in a special soundfile.
The format of this special soundfile is $N+2$ channels 
($N/2 + 1$ amplitude channels and 
$N/2 + 1$ frequency channels all interleaved).
Odd channels are time varying amplitudes and even channels are time varying
frequencies (channels are numbered 1 through N+2).  
The first two channels contain the amplitude and frequency
of the DC (zero frequency) filter, so the data for the
fundamental is usually in channels 3 (amplitude) and 4 (frequency).
.PP
The general additive synthesis shown in Figure 14 may be replaced
by a simple oscillator with a sndfile unit generator controlling its amplitude
and another controlling its frequency for each of the $N+2$ analysis channels.
Only one such cmusic instrument needs to be defined, of course, since it is
possible to effect the resynthesis by playing $N+2$ simultaneous notes on it,
each contributing a single additive component to the resulting sound.
.PP
Needless to say, the special soundfile that holds the analysis results
can be quite large.
Its size is determined by the number of pvoc channels ($N$), and the amount
of window overlap used in the analysis.
.Nh 1 "APPENDIX I: The cmusic Command"
.DS
cmusic [ \(mio ] [ [ \(miv ] [ \(min ] [ \(mit ] [ \(miq ] [ \(miRx ] [ \(miLx ] [ \(miBx ] [ score_file ] > output
.DE
.PP
cmusic flags given on the command line override options in
the score_file.
.RS
.IP \(mio   
tells cmusic to produce no sample output (debug mode)
.IP \(miv   
sets the verbose option; \(miv\(mi turns it off (default = off).
.IP \(min   
sets the notify option; \(min\(mi turns it off (default = off).
.IP \(mit   
sets the timer option; \(mit\(mi turns it off (default = off).
.IP \(miq   
turns off any verbose, timer, or notify options set elsewhere.
.IP \(miRx  
sets the sampling rate to x (default = 16K).
.IP \(miLx  
sets the default function length to x (default default = 1K).
.IP \(miBx  
sets the io block length to x (default = 256).
.RE
.PP
Flag symbols must not be combined, i.e., ``\(mitn'' will not
work, but ``\(mit \(min'' will.
.PP
If no score_file is given, cmusic reads its standard input.
.PP
If its standard output is connected to a terminal, cmusic
generates ASCII sample values on the screen; if the standard
output is not a terminal, binary values (floats by default)
are produced.  
.PP
Detected score errors generally cause sample
synthesis to stop\(emthe remainder of the score is scanned
for further errors, if possible.
.Nh 1 "APPENDIX II: Sample Score Files"
.PP
A few briefly annotated score examples are included here for reference.
These scores are intended only to give a flavor the the idiomatic
use of the cmusic score language, and are not compositional models.
.PP
The following score synthesizes several notes with just
pitch and just and tempered timbres.
.sp 2
.nf
#include <carl/cmusic.h>
set list ;
set funclength = 8K ;
set srate = 48K ;
ins 0 comp ;
{envelope}      osc  b1 p5 p7 f2 d ;
{carrier}       osc  b1 b1 p6 f1 d ;
{output}        out  b1 ;
end ;

GEN2(f1) 1 1 ;
GEN4(f2) 0,0 \(mi2 .2,1 \(mi1 .5,.5 \(mi2 1,0 ;

#define AMP (\(mi18dB)

#define TEMP(time, dur, amp, pitch)\\
note time comp dur amp pitch P ;\\
note time comp dur amp/2 pitch*2 P ;\\
note time comp dur amp/3 pitch*2*2^(7/12) P ;\\
note time comp dur amp/4 pitch*4 P ;\\
note time comp dur amp/5 pitch*4*2^(4/12) P

#define JUST(time, dur, amp, pitch)\\
note time comp dur amp pitch P ;\\
note time comp dur amp/2 pitch*2 P ;\\
note time comp dur amp/3 pitch*3 P ;\\
note time comp dur amp/4 pitch*4 P ;\\
note time comp dur amp/5 pitch*5 P

{
JUST(0,2,(\(mi30dB),(C(0))) ;
sec ;
sec .5 ;
TEMP(0,2,(\(mi30dB),(C(0))) ;
sec ;
sec .5 ;
}

JUST(0,1.5,(\(mi30dB),(P1(\(mi2)*C(0))) ;      {(C(\(mi2))) ;}
JUST(0,1.5,(\(mi30dB),(P1(\(mi1)*C(0))) ;      {(C(\(mi1))) ;}
JUST(0,1.5,(\(mi30dB),(P5(\(mi1)*C(0))) ;      {(G(\(mi1))) ;}
JUST(0,1.5,(\(mi30dB),(P1(0)*C(0))) ;       {(C(0))) ;}
JUST(0,1.5,(\(mi30dB),(M3(0)*C(0))) ;       {(E(0))) ;}
JUST(0,1.5,(\(mi30dB),(P5(0)*C(0))) ;       {(G(0))) ;}

JUST(2,8,(\(mi24dB),(P1(\(mi2)*P4(0)*C(0))) ;  {(F(\(mi2))) ;}
JUST(2,8,(\(mi24dB),(P5(\(mi2)*P4(0)*C(0))) ;  {(C(\(mi1))) ;}
JUST(2,8,(\(mi24dB),(M3(\(mi1)*P4(0)*C(0))) ;  {(A(\(mi1))) ;}
JUST(2,8,(\(mi24dB),(P5(\(mi1)*P4(0)*C(0))) ;  {(C(0))) ;}
JUST(2,8,(\(mi24dB),(M7(\(mi1)*P4(0)*C(0))) ;  {(E(0))) ;}
JUST(2,8,(\(mi24dB),(M2(0)*P4(0)*C(0))) ;   {(G(0))) ;}

JUST(10,1.5,(\(mi24dB),(P1(\(mi3)*P4(0)*C(0))) ; {(F(\(mi3))) ;}
JUST(10,1.5,(\(mi24dB),(P1(\(mi2)*P4(0)*C(0))) ; {(F(\(mi2))) ;}
JUST(10,1.5,(\(mi24dB),(M3(\(mi1)*P4(0)*C(0))) ; {(A(\(mi1))) ;}
JUST(10,1.5,(\(mi24dB),(P5(\(mi1)*P4(0)*C(0))) ; {(C(0))) ;}
JUST(10,1.5,(\(mi24dB),(m7(\(mi1)*P4(0)*C(0))) ; {(Ef(0))) ;}
JUST(10,1.5,(\(mi24dB),(M2(0)*P4(0)*C(0))) ;  {(G(0))) ;}

JUST(12,8,(\(mi24dB),(P1(\(mi3)*C(0))) ;         {(C(\(mi3))) ;}
JUST(12,8,(\(mi24dB),(P5(\(mi2)*C(0))) ;         {(G(\(mi2))) ;}
JUST(12,8,(\(mi24dB),(P1(0)*C(0))) ;          {(C(0))) ;}
JUST(12,8,(\(mi24dB),(M3(0)*C(0))) ;          {(E(0))) ;}
JUST(12,8,(\(mi24dB),(P5(0)*C(0))) ;          {(G(0))) ;}
JUST(12,8,(\(mi24dB),(M7(0)*C(0))) ;          {(B(0))) ;}

sec ;
sec 2 ;

TEMP(0,1.5,(\(mi30dB),(P1(\(mi2)*C(0))) ;        {(C(\(mi2))) ;}
TEMP(0,1.5,(\(mi30dB),(P1(\(mi1)*C(0))) ;        {(C(\(mi1))) ;}
TEMP(0,1.5,(\(mi30dB),(P5(\(mi1)*C(0))) ;        {(G(\(mi1))) ;}
TEMP(0,1.5,(\(mi30dB),(P1(0)*C(0))) ;         {(C(0))) ;}
TEMP(0,1.5,(\(mi30dB),(M3(0)*C(0))) ;         {(E(0))) ;}
TEMP(0,1.5,(\(mi30dB),(P5(0)*C(0))) ;         {(G(0))) ;}

TEMP(2,8,(\(mi24dB),(P1(\(mi2)*P4(0)*C(0))) ;    {(F(\(mi2))) ;}
TEMP(2,8,(\(mi24dB),(P5(\(mi2)*P4(0)*C(0))) ;    {(C(\(mi1))) ;}
TEMP(2,8,(\(mi24dB),(M3(\(mi1)*P4(0)*C(0))) ;    {(A(\(mi1))) ;}
TEMP(2,8,(\(mi24dB),(P5(\(mi1)*P4(0)*C(0))) ;    {(C(0))) ;}
TEMP(2,8,(\(mi24dB),(M7(\(mi1)*P4(0)*C(0))) ;    {(E(0))) ;}
TEMP(2,8,(\(mi24dB),(M2(0)*P4(0)*C(0))) ;     {(G(0))) ;}

TEMP(10,1.5,(\(mi24dB),(P1(\(mi3)*P4(0)*C(0))) ; {(F(\(mi3))) ;}
TEMP(10,1.5,(\(mi24dB),(P1(\(mi2)*P4(0)*C(0))) ; {(F(\(mi2))) ;}
TEMP(10,1.5,(\(mi24dB),(M3(\(mi1)*P4(0)*C(0))) ; {(A(\(mi1))) ;}
TEMP(10,1.5,(\(mi24dB),(P5(\(mi1)*P4(0)*C(0))) ; {(C(0))) ;}
TEMP(10,1.5,(\(mi24dB),(m7(\(mi1)*P4(0)*C(0))) ; {(Ef(0))) ;}
TEMP(10,1.5,(\(mi24dB),(M2(0)*P4(0)*C(0))) ;  {(G(0))) ;}

TEMP(12,8,(\(mi24dB),(P1(\(mi3)*C(0))) ;         {(C(\(mi3))) ;}
TEMP(12,8,(\(mi24dB),(P5(\(mi2)*C(0))) ;         {(G(\(mi2))) ;}
TEMP(12,8,(\(mi24dB),(P1(0)*C(0))) ;          {(C(0))) ;}
TEMP(12,8,(\(mi24dB),(M3(0)*C(0))) ;          {(E(0))) ;}
TEMP(12,8,(\(mi24dB),(P5(0)*C(0))) ;          {(G(0))) ;}
TEMP(12,8,(\(mi24dB),(M7(0)*C(0))) ;          {(B(0))) ;}

ter ;
.bp
.fi
.PP
The following score defines a frequency-modulated instrument
and plays a note on it.
.sp 2
.nf
#include <carl/cmusic.h>
set funclength = 8K ;
set list ;

ins 0 fm ; {p5:p4sec, p6:peak amp, p7:fc}
    {amp env}   osc b1 p6 p5 f2 d ;
    {df env}    osc b2 1 p5 f3 d ;
    {fm env}    osc b3 1 p5 f4 d ;
    {mod osc}   osc b5 b2 b3 f1 d ;
    {sum}       adn b6 b5 p7 ;
    {carrier}   osc b7 b1 b6 f1 d ;
    {output}    out b7 ;
end ; 
{f1 \(mi sine}
SINE(f1) ;
{f2 \(mi amp env}
GEN4(f2) 0,0 \(mi1 .05,1 0 .95,1 \(mi2 1,0 ;
{f3 \(mi df env}
GEN4(f3) 0,0 0 1/8,6Hz 0 2/8,12Hz 0 3/8,300Hz 0 4/8,900Hz 0 
             7/8,900Hz 0 8/8,0 ;
{f4 \(mi fm env}
GEN4(f4) 0,1.5Hz (ln(2)) 4/8,3Hz (ln(100)) 7/8,300Hz 0 1,300Hz ;

note 0 fm 32 p4sec \(mi12dB 300Hz ;

ter ;
.bp
.fi
The following score exploits cmusic macros in order to create a
score shorthand similar to music notation.
.nf
.sp 2
#include <carl/cmusic.h>

set notify ;
set func = 4K ;

ins 0 t ;
    seg b2 1 f2 d 0 ;
    mult b5 b2 p5 ;
    mult b3 b2 p8 ;
    osc b4 b3 p7 f1 d ;
    adn b4 b4 p6 ;
    osc b1 b5 b4 f1 d ;
    out b1 ;
end ;
{p5\(miamp ; p6\(miFc ; p7\(miFm ; p8\(midF ;}
ins 0 o ;
    seg b2 1 f4 d 0 ;
    mult b5 b2 p5 ;
    mult b3 b2 p8 ;
    osc b4 b3 p7 f1 d ;
    adn b4 b4 p6 ;
    osc b1 b5 b4 f1 d ;
    out b1 ;
end ;
ins 0 b ;
    seg b2 1 f4 d 0 ;
    mult b5 b2 p5 ;
    mult b3 b2 p8 ;
    osc b4 b3 p7 f1 d ;
    adn b4 b4 p6 ;
    osc b1 b5 b4 f1 d ;
    out b1 ;
end ;
SINE(f1) ;
GEN4(f2) 0,0 \(mi2 .1,1 0 .8,.5 \(mi2 1,0 ;
GEN5(f3) 1,1,0 2,1,0 3,1/2,0 4,1,0 5,1/3,0 6,1/4,0 7,1/5,0 ;
NORM(f3) ;
GEN4(f4) 0,0 \(mi3 .1,1 0 .9,1 0 1,0 ;

#define amp (1/10)
#define T (4*(180MM))
#define STAC .6
#define NON .9
#define LEG 1.1
#define INDEX 7
#define HARM 1
{Macro to play a note AFTER the last one in the score}
#define NEXT(ins,pitch,dur,duty)\\
note p2+p4 ins T*duty/(dur) amp   pitch  HARM*p6  INDEX*p7 ;\\
note p2 ins T*duty/(dur) amp   pitch/2  HARM*p6  INDEX*p7 ;\\
var  p2  p4  T/(dur)

{Macro to play a note WITH the last one in the score}
#define SAME(ins,pitch,dur,duty)\\
var  p2    v1 p4 ;\\
note p2    ins T*duty/(dur) amp   pitch HARM*p6  INDEX*p7 ;\\
note p2    ins T*duty/(dur) amp   pitch/2 HARM*p6  INDEX*p7 ;\\
var  p2    p4 v1

{Chord Macros}
#define CH2(p1,p2,ins,dur,duty)\\
 NEXT(ins,p1,dur,duty) ; SAME(ins,p2\(mi.5,dur,duty)

#define CHS2(p1,p2,ins,dur,duty)\\
 SAME(ins,p1,dur,duty) ; SAME(ins,p2\(mi.5,dur,duty)

#define CH3(p1,p2,p3,ins,dur,duty)\\
 NEXT(ins,p1,dur,duty) ; SAME(ins,p2\(mi.5,dur,duty) ; SAME(ins,p3\(mi.7,dur,duty)

#define CHS3(p1,p2,p3,ins,dur,duty)\\
 SAME(ins,p1,dur,duty) ; SAME(ins,p2\(mi.5,dur,duty) ; SAME(ins,p3\(mi.7,dur,duty)

#define CH4(p1,p2,p3,p4,ins,dur,duty)\\
 NEXT(ins,p1,dur,duty) ;SAME(ins,p2,dur,duty) ;\\
  SAME(ins,p3,dur,duty) ;SAME(ins,p4,dur,duty)

#define CHS4(p1,p2,p3,p4,ins,dur,duty)\\
 SAME(ins,p1,dur,duty) ;SAME(ins,p2,dur,duty) ;\\
  SAME(ins,p3,dur,duty) ;SAME(ins,p4,dur,duty)

{Notelist begins here \(mi tune is by Mendelssohn}

    CH3(C(0),C(0),C(0),t,4*3,STAC) ;
     CH3(C(0),C(0),C(0),t,4*3,STAC) ;
      CH3(C(0),C(0),C(0),t,4*3,STAC) ;
CH3(C(0),C(0),C(0),t,4/3,NON) ;

 CH3(C(0),C(0),C(0),t,4*3,STAC) ;
  CH3(C(0),C(0),C(0),t,4*3,STAC) ;
   CH3(C(0),C(0),C(0),t,4*3,STAC) ;
CH3(C(0),C(0),C(0),t,4/3,NON) ;

 CH3(C(0),C(0),C(0),t,4*3,STAC) ;
  CH3(C(0),C(0),C(0),t,4*3,STAC) ;
   CH3(C(0),C(0),C(0),t,4*3,STAC) ;
CH3(C(0),E(0),E(0),t,4,STAC) ;

 CH3(C(0),E(0),E(0),t,4*3,STAC) ;
  CH3(C(0),E(0),E(0),t,4*3,STAC) ;
   CH3(C(0),E(0),E(0),t,4*3,STAC) ;
    CH3(C(0),E(0),E(0),t,4,STAC) ;

     CH3(C(0),E(0),E(0),t,4*3,STAC) ;
      CH3(C(0),E(0),E(0),t,4*3,STAC) ;
       CH3(C(0),E(0),E(0),t,4*3,STAC) ;
CH3(C(0),E(0),G(0),t,4,STAC) ;

 CH3(C(0),E(0),G(0),t,4*3,STAC) ;
  CH3(C(0),E(0),G(0),t,4*3,STAC) ;
   CH3(C(0),E(0),G(0),t,4*3,STAC) ;
    CH3(C(0),E(0),G(0),t,4,STAC) ;

     CH3(C(0),E(0),G(0),t,4*3,STAC) ;
      CH3(C(0),E(0),G(0),t,4*3,STAC) ;
       CH3(C(0),E(0),G(0),t,4*3,STAC) ;
CH4(C(1),E(1),Fs(1),C(2),o,2,LEG) ; 
		    CHS3(E(0),Fs(0),C(1),t,2,STAC) ;CHS2(A(\(mi3),A(\(mi2),b,2,LEG) ;
 CH4(B(0),Ds(1),Fs(1),B(1),o,16/7,LEG) ; CHS2(B(\(mi3),B(\(mi2),b,2,LEG) ;
  CH4(B(0),Ds(1),Fs(1),Fs(1),o,16,NON) ;
CH4(B(0),Ds(1),Fs(1),A(1),o,4,LEG) ; CHS2(E(\(mi3),E(\(mi2),b,2,LEG) ;
 CH4(B(0),E(1),G(1),G(1),o,4,LEG) ;
  CH4(A(0),D(1),F(1),F(1),o,4,NON) ; CHS2(F(\(mi3),F(\(mi2),b,2,LEG) ;
   CH4(F(0),A(0),D(1),D(1),o,4,NON) ;
 CH4(E(0),G(0),C(1),C(1),o,2*9,LEG) ; CHS2(G(\(mi3),G(\(mi2),b,2,LEG) ;
  CH4(F(0),F(0),D(1),D(1),o,2*9,NON) ; 
   CH4(E(0),E(0),C(1),C(1),o,2*9,NON) ; 
    CH4(F(0),F(0),D(1),D(1),o,2*9,NON) ; 
     CH4(E(0),E(0),C(1),C(1),o,2*9,NON) ; 
      CH4(F(0),F(0),D(1),D(1),o,2*9,NON) ; 
       CH4(E(0),E(0),C(1),C(1),o,2*9,NON) ; 
        CH4(D(0),D(0),B(0),B(0),o,2*9,NON) ; 
         CH4(E(0),E(0),C(1),C(1),o,2*9,NON) ; 
 CH4(F(0),G(0),B(0),D(1),o,4,STAC) ; CHS2(G(\(mi3),G(\(mi2),b,2,LEG) ;
  CH4(F(0),G(0),G(0),G(0),o,16/3,STAC) ;
   CH4(F(0),G(0),B(0),D(1),o,16,NON) ;
 CH4(E(0),G(0),C(1),E(1),o,4,LEG) ; CHS2(C(\(mi3),C(\(mi2),b,2,LEG) ;
  CH3(C(0),C(0),C(0),t,8,NON) ;
   CH3(E(0),E(0),E(0),t,8,NON) ;
    CH3(G(0),G(0),G(0),t,8,NON) ;
     CH3(C(1),C(1),C(1),t,8,NON) ;
      CH3(C(1),E(1),E(1),t,8,NON) ;
       CH3(C(1),E(1),G(1),t,8,NON) ;
CH2(A(\(mi3),A(\(mi2),b,4,LEG) ; CHS4(C(1),E(1),Fs(1),C(2),o,2,LEG) ; 
	    CHS3(E(1),Fs(1),C(2),t,2,STAC) ;
 CH2(Fs(\(mi3),Fs(\(mi2),b,4,LEG) ; 
  CH2(B(\(mi3),B(\(mi2),b,4,LEG) ; CHS4(B(0),Ds(1),Fs(1),B(1),o,2,LEG) ; 
   CH2(Ds(\(mi3),Ds(\(mi2),b,16/3,LEG) ; 
    CH4(B(0),Ds(1),Fs(1),Fs(1),o,16,NON) ;
CH4(B(0),Ds(1),Fs(1),A(1),o,4,LEG) ; CHS2(E(\(mi3),E(\(mi2),b,4,LEG) ;
 CH4(B(0),E(1),G(1),G(1),o,4,LEG) ; CHS2(G(\(mi3),G(\(mi2),b,4,LEG) ;
  CH4(A(0),D(1),F(1),F(1),o,4,NON) ; CHS2(F(\(mi3),F(\(mi2),b,4,LEG) ;
   CH4(F(0),A(0),D(1),D(1),o,4,NON) ; CHS2(A(\(mi3),A(\(mi2),b,4,LEG) ;
 CH4(E(0),G(0),C(1),C(1),o,2*9,LEG) ; CHS2(G(\(mi3),G(\(mi2),b,2,LEG) ;
  CH4(F(0),F(0),D(1),D(1),o,2*9,NON) ; 
   CH4(E(0),E(0),C(1),C(1),o,2*9,NON) ; 
    CH4(F(0),F(0),D(1),D(1),o,2*9,NON) ; 
     CH4(E(0),E(0),C(1),C(1),o,2*9,NON) ; 
      CH4(F(0),F(0),D(1),D(1),o,2*9,NON) ; 
       CH4(E(0),E(0),C(1),C(1),o,2*9,NON) ; 
        CH4(D(0),D(0),B(0),B(0),o,2*9,NON) ; 
         CH4(E(0),E(0),C(1),C(1),o,2*9,NON) ; 
 CH4(E(0),G(0),C(1),E(1),o,4,NON) ; CHS2(G(\(mi3),G(\(mi2),b,4,LEG) ;
  CH4(F(0),G(0),B(0),D(1),o,16/3,NON) ; CHS2(G(\(mi3),G(\(mi2),b,4,LEG) ;
   CH4(G(0),G(0),C(0),E(1),o,16,STAC) ;
    CH2(G(\(mi2),G(\(mi1),b,4,STAC) ; CHS4(F(0),G(0),B(0),D(1),o,2,LEG) ; 
     CH2(G(\(mi3),G(\(mi2),b,4,NON) ;
CH4(E(0),G(0),C(1),C(1),o,4,NON) ; CHS2(C(\(mi3),C(\(mi2),b,4,NON) ;
CH4(C(1),E(1),G(1),C(2),o,4,STAC) ; CHS2(C(\(mi2),G(\(mi2),b,4,STAC) ;
    CHS3(C(1),E(0),G(0),t,3,STAC) ;
ter ;
.bp
.SH
Acknowledgment
.PP
The author thanks Gareth Loy and Lee Ray for careful and timely 
proofreading of this document.
